@@ -1,5 +1,6 @@
 class Config:
     Api = "https://api.fyers.in/api/v2"
+    data_Api= "https://api.fyers.in/data-rest/v2"
 
     get_profile = '/profile'
     tradebook = '/tradebook'
@@ -19,3 +20,6 @@ class Config:
     dataVendorTD = "truedata-ws"
 
     multi_orders = '/orders-multi'
+    history = '/history/'
+    quotes = '/quotes/'
+    market_depth = '/depth/'
\ No newline at end of file
