@@ -216,3 +216,33 @@ class FyersModel:
 		except Exception as e:
 			self.logObj.logEntryFunc(str(int(datetime.now(tz=timezone.utc).timestamp() * 1000)), "modify_basket_orders", data, "response", "ERROR  : {}".format(e))
 			return
+
+	def history(self,data=None):
+		try: 
+			timestamp = self.create_timestamp()
+			response = self.service.getCall(Config.history, self.header, data,data_flag=True)
+			self.logObj.logEntryFunc(timestamp, "history", data, response)
+			return response
+		except Exception as e:
+			self.logObj.logEntryFunc(str(int(datetime.now(tz=timezone.utc).timestamp() * 1000)), "history", data, "response", "ERROR  : {}".format(e))
+			return
+
+	def quotes(self,data=None):
+		try: 
+			timestamp = self.create_timestamp()
+			response = self.service.getCall(Config.quotes, self.header, data,data_flag=True)
+			self.logObj.logEntryFunc(timestamp, "quotes", data, response)
+			return response
+		except Exception as e:
+			self.logObj.logEntryFunc(str(int(datetime.now(tz=timezone.utc).timestamp() * 1000)), "history", data, "response", "ERROR  : {}".format(e))
+			return
+
+	def depth(self,data=None):
+		try: 
+			timestamp = self.create_timestamp()
+			response = self.service.getCall(Config.market_depth, self.header, data,data_flag=True)
+			self.logObj.logEntryFunc(timestamp, "depth", data, response)
+			return response
+		except Exception as e:
+			self.logObj.logEntryFunc(str(int(datetime.now(tz=timezone.utc).timestamp() * 1000)), "history", data, "response", "ERROR  : {}".format(e))
+			return
\ No newline at end of file
