@@ -31,9 +31,12 @@ class FyersService:
             return response
         return response.json()
 
-    def getCall(self, api, header, data=None):
+    def getCall(self, api, header, data=None,data_flag=False):
         try:
-            url = Config.Api + api
+            if data_flag:
+                url = Config.data_Api + api
+            else:
+                url = Config.Api + api
             if data is not None:
                 try:
                     url_params = urllib.urlencode(data)
